@@ -11,17 +11,17 @@ class AceWidget(Textarea):
         classes = [x.strip() for x in new_attrs.get("class", "").split()]
         classes.append("django-fastadmin-ace-widget")
         new_attrs["class"] = " ".join(classes)
-        new_attrs["ace-options"] = json.dumps(ace_options)
+        new_attrs["ace-widget-options"] = json.dumps(ace_options)
         super().__init__(new_attrs)
 
     class Media:
         css = {
             "screen": [
-                "django-fastadmin/widgets/ace/ace-widget.css",
+                "fastadmin/widgets/ace-widget/ace-widget.css",
             ]
         }
         js = jquery_plugins([
-            "ace/ace.js",
-            "django-jquery-plugins/jquery.utils.js",
-            "django-fastadmin/widgets/ace/ace-widget.js",
+            "ace-builds/ace.js",
+            "jquery/plugins/jquery.utils.js",
+            "fastadmin/widgets/ace-widget/ace-widget.js",
         ])
